from distutils.core import setup

setup(
    name='beer_beer',
    version='1.0.0',
    author='Terry Wong',
    author_email='terrywpl@gmail.com',
    url='http://google.com',
    description='calculate how many beer can buy',
    py_modules=['Beer'],
)